# compass.api_client


<h3>With this API you can:</h3>
<ul>
<li><strong>Execute complex DeFi transactions:&nbsp; </strong>Swap, lend, borrow, stake, LP, and more, with high-level on-chain actions.</li>
<li><strong>Stay secure &amp; non-custodial</strong> &ndash; Transactions are signed locally, and you retain full control.</li>
<li><strong>Build AI &amp; automation workflows</strong> &ndash; Power AI agents, trading bots, yield products and DeFi applications with programmatic transaction execution. Integrate seamlessly into existing workflows.</li>
<li><strong>Interact across multiple protocols &amp; chains</strong>&nbsp;&ndash; Spot, lending, staking on Ethereum, Arbitrum, Base. Many more to come!</li>
</ul>

<h3 id=\"quick-links\" class=\"docs-chapter-header\"><a class=\"not-prose group hover:text-compass-pink transition-colors flex w-fit\" href=\"https://www.compasslabs.ai/api-docs#quick-links\">Quick links</a></h3>
<ul>
<li><a href=\"https://api.compasslabs.ai/\" target=\"_blank\" rel=\"noopener\">API reference</a></li>
<li><a href=\"https://github.com/CompassLabs/compass_api_examples\" target=\"_blank\" rel=\"noopener\">5 min quickstart</a></li>
<li><a href=\"https://discord.gg/qjP8dCYZ58\" target=\"_blank\" rel=\"noopener\">Discord</a></li>
<li><a href=\"https://www.compasslabs.ai/\" target=\"_blank\" rel=\"noopener\">Compass Labs</a></li>
</ul>

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.1
- Package version: 1.0.85
- Generator version: 7.13.0-SNAPSHOT
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import compass.api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import compass.api_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import compass.api_client
from compass.api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.compasslabs.ai
# See configuration.py for a list of all supported configuration parameters.
configuration = compass.api_client.Configuration(
    host = "https://api.compasslabs.ai"
)



# Enter a context with an instance of the API client
with compass.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = compass.api_client.AaveV3Api(api_client)
    aave_get_asset_price = compass.api_client.AaveGetAssetPrice() # AaveGetAssetPrice | 

    try:
        # Get the price of an asset in USD according to Aave
        api_response = api_instance.process_request_v0_aave_asset_price_get_post(aave_get_asset_price)
        print("The response of AaveV3Api->process_request_v0_aave_asset_price_get_post:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AaveV3Api->process_request_v0_aave_asset_price_get_post: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.compasslabs.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AaveV3Api* | [**process_request_v0_aave_asset_price_get_post**](docs/AaveV3Api.md#process_request_v0_aave_asset_price_get_post) | **POST** /v0/aave/asset_price/get | Get the price of an asset in USD according to Aave
*AaveV3Api* | [**process_request_v0_aave_borrow_post**](docs/AaveV3Api.md#process_request_v0_aave_borrow_post) | **POST** /v0/aave/borrow | Borrow against your collateral
*AaveV3Api* | [**process_request_v0_aave_liquidity_change_get_post**](docs/AaveV3Api.md#process_request_v0_aave_liquidity_change_get_post) | **POST** /v0/aave/liquidity/change/get | Gets the change in liquidity index between two blocks, therefore the amount a position will have increased or decreased over the time
*AaveV3Api* | [**process_request_v0_aave_repay_post**](docs/AaveV3Api.md#process_request_v0_aave_repay_post) | **POST** /v0/aave/repay | Repay some or all tokens you borrowed
*AaveV3Api* | [**process_request_v0_aave_supply_post**](docs/AaveV3Api.md#process_request_v0_aave_supply_post) | **POST** /v0/aave/supply | Supply collateral to earn interest or borrow against
*AaveV3Api* | [**process_request_v0_aave_user_position_per_token_get_post**](docs/AaveV3Api.md#process_request_v0_aave_user_position_per_token_get_post) | **POST** /v0/aave/user_position_per_token/get | Get the user&#39;s position for a specific token.
*AaveV3Api* | [**process_request_v0_aave_user_position_summary_get_post**](docs/AaveV3Api.md#process_request_v0_aave_user_position_summary_get_post) | **POST** /v0/aave/user_position_summary/get | Get a summary of the user&#39;s position on AAVE. These values will be sums or averages across all open positions.
*AaveV3Api* | [**process_request_v0_aave_withdraw_post**](docs/AaveV3Api.md#process_request_v0_aave_withdraw_post) | **POST** /v0/aave/withdraw | Withdraw some or all of your collateral
*AerodromeBasicApi* | [**process_request_v0_aerodrome_basic_liquidity_provision_add_liquidity_eth_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_liquidity_provision_add_liquidity_eth_post) | **POST** /v0/aerodrome_basic/liquidity_provision/add_liquidity_eth | Provide liquidity to a pool on Aerodrome using WETH and another token
*AerodromeBasicApi* | [**process_request_v0_aerodrome_basic_liquidity_provision_add_liquidity_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_liquidity_provision_add_liquidity_post) | **POST** /v0/aerodrome_basic/liquidity_provision/add_liquidity | Provide liquidity to a pool on Aerodrome
*AerodromeBasicApi* | [**process_request_v0_aerodrome_basic_liquidity_provision_remove_liquidity_eth_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_liquidity_provision_remove_liquidity_eth_post) | **POST** /v0/aerodrome_basic/liquidity_provision/remove_liquidity_eth | Remove liquidity from a pool on Aerodrome using WETH and another token
*AerodromeBasicApi* | [**process_request_v0_aerodrome_basic_liquidity_provision_remove_liquidity_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_liquidity_provision_remove_liquidity_post) | **POST** /v0/aerodrome_basic/liquidity_provision/remove_liquidity | Remove liquidity from a pool on Aerodrome
*AerodromeBasicApi* | [**process_request_v0_aerodrome_basic_swap_eth_for_token_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_swap_eth_for_token_post) | **POST** /v0/aerodrome_basic/swap/eth_for_token | Swap ETH for some of a token on Aerodrome
*AerodromeBasicApi* | [**process_request_v0_aerodrome_basic_swap_token_for_eth_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_swap_token_for_eth_post) | **POST** /v0/aerodrome_basic/swap/token_for_eth | Swap a token for ETH on Aerodrome
*AerodromeBasicApi* | [**process_request_v0_aerodrome_basic_swap_tokens_post**](docs/AerodromeBasicApi.md#process_request_v0_aerodrome_basic_swap_tokens_post) | **POST** /v0/aerodrome_basic/swap/tokens | Swap one token for another token on Aerodrome
*AerodromeSlipstreamApi* | [**process_request_v0_aerodrome_slipstream_liquidity_provision_increase_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_liquidity_provision_increase_post) | **POST** /v0/aerodrome_slipstream/liquidity_provision/increase | Increase an LP position
*AerodromeSlipstreamApi* | [**process_request_v0_aerodrome_slipstream_liquidity_provision_mint_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_liquidity_provision_mint_post) | **POST** /v0/aerodrome_slipstream/liquidity_provision/mint | Open a new LP position
*AerodromeSlipstreamApi* | [**process_request_v0_aerodrome_slipstream_liquidity_provision_positions_get_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_liquidity_provision_positions_get_post) | **POST** /v0/aerodrome_slipstream/liquidity_provision/positions/get | Get the number of LP positions for a given sender
*AerodromeSlipstreamApi* | [**process_request_v0_aerodrome_slipstream_liquidity_provision_withdraw_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_liquidity_provision_withdraw_post) | **POST** /v0/aerodrome_slipstream/liquidity_provision/withdraw | Withdraw a LP position
*AerodromeSlipstreamApi* | [**process_request_v0_aerodrome_slipstream_pool_price_get_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_pool_price_get_post) | **POST** /v0/aerodrome_slipstream/pool_price/get | Get the current price of a pool (how many token0 you can buy for 1 token1). This is only the instantaneous price; during any trade the price will change. Use the quote endpoint to get a more realistic idea of the ratios of the two assets you could trade.
*AerodromeSlipstreamApi* | [**process_request_v0_aerodrome_slipstream_swap_buy_exactly_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_swap_buy_exactly_post) | **POST** /v0/aerodrome_slipstream/swap/buy_exactly | Trade the amount of a token it takes to end up with a specified quantity of the other token
*AerodromeSlipstreamApi* | [**process_request_v0_aerodrome_slipstream_swap_sell_exactly_post**](docs/AerodromeSlipstreamApi.md#process_request_v0_aerodrome_slipstream_swap_sell_exactly_post) | **POST** /v0/aerodrome_slipstream/swap/sell_exactly | Trade a specific amount of a token into another.
*OthersApi* | [**get_tokens_v0_generic_supported_tokens_get_post**](docs/OthersApi.md#get_tokens_v0_generic_supported_tokens_get_post) | **POST** /v0/generic/supported_tokens/get | Get supported token
*OthersApi* | [**process_request_v0_generic_allowance_get_post**](docs/OthersApi.md#process_request_v0_generic_allowance_get_post) | **POST** /v0/generic/allowance/get | Show the allowance of a user on a protocol
*OthersApi* | [**process_request_v0_generic_allowance_set_any_post**](docs/OthersApi.md#process_request_v0_generic_allowance_set_any_post) | **POST** /v0/generic/allowance/set_any | Sets allowance for any arbitrary ERC20 token address.
*OthersApi* | [**process_request_v0_generic_allowance_set_post**](docs/OthersApi.md#process_request_v0_generic_allowance_set_post) | **POST** /v0/generic/allowance/set | Change the allowance of a user on a protocol
*OthersApi* | [**process_request_v0_generic_balance_get_post**](docs/OthersApi.md#process_request_v0_generic_balance_get_post) | **POST** /v0/generic/balance/get | Get an address balance of a token
*OthersApi* | [**process_request_v0_generic_ens_get_post**](docs/OthersApi.md#process_request_v0_generic_ens_get_post) | **POST** /v0/generic/ens/get | Get the wallet address and registrant of an ENS name
*OthersApi* | [**process_request_v0_generic_portfolio_get_post**](docs/OthersApi.md#process_request_v0_generic_portfolio_get_post) | **POST** /v0/generic/portfolio/get | Get the portfolio details for a wallet addressincluding balances and values of all tokens.
*OthersApi* | [**process_request_v0_generic_unwrap_weth_post**](docs/OthersApi.md#process_request_v0_generic_unwrap_weth_post) | **POST** /v0/generic/unwrap_weth | Change WETH into raw ETH
*OthersApi* | [**process_request_v0_generic_visualize_portfolio_get_post**](docs/OthersApi.md#process_request_v0_generic_visualize_portfolio_get_post) | **POST** /v0/generic/visualize_portfolio/get | Visualize the token portfolio of a wallet address as a pie chart
*OthersApi* | [**process_request_v0_generic_wrap_eth_post**](docs/OthersApi.md#process_request_v0_generic_wrap_eth_post) | **POST** /v0/generic/wrap_eth | Change raw ETH into WETH
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_impermanent_loss_get_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_impermanent_loss_get_post) | **POST** /v0/uniswap/liquidity_provision/impermanent_loss/get | Calculate the impermanent loss of a liquidity position on Uniswap.
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_in_range_get_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_in_range_get_post) | **POST** /v0/uniswap/liquidity_provision/in_range/get | Check if a position is in active tick range
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_increase_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_increase_post) | **POST** /v0/uniswap/liquidity_provision/increase | Increase an LP position
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_mint_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_mint_post) | **POST** /v0/uniswap/liquidity_provision/mint | Open a new LP position
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_positions_get_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_positions_get_post) | **POST** /v0/uniswap/liquidity_provision/positions/get | Retrieve LP positions for a sender
*UniswapV3Api* | [**process_request_v0_uniswap_liquidity_provision_withdraw_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_liquidity_provision_withdraw_post) | **POST** /v0/uniswap/liquidity_provision/withdraw | Withdraw a LP position
*UniswapV3Api* | [**process_request_v0_uniswap_pool_price_get_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_pool_price_get_post) | **POST** /v0/uniswap/pool_price/get | Get the current price of a pool (how many token0 you can buy for 1 token1). This is only the instantaneous price; during any trade the price will change. Use the quote endpoint to get a more realistic idea of the ratios of the two assets you could trade.
*UniswapV3Api* | [**process_request_v0_uniswap_quote_buy_exactly_get_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_quote_buy_exactly_get_post) | **POST** /v0/uniswap/quote/buy_exactly/get | Get the amount of tokens you would need to provide to the pool in order to purchase a fixed quantity of tokens. Also returns what the price would be afterwards.
*UniswapV3Api* | [**process_request_v0_uniswap_quote_sell_exactly_get_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_quote_sell_exactly_get_post) | **POST** /v0/uniswap/quote/sell_exactly/get | Get the amount of tokens you would get from the pool if you provided a fixed quantity of tokens. Also returns what the price would be afterwards.
*UniswapV3Api* | [**process_request_v0_uniswap_swap_buy_exactly_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_swap_buy_exactly_post) | **POST** /v0/uniswap/swap/buy_exactly | Trade the amount of a token it takes to end up with a specified quantity of the other token
*UniswapV3Api* | [**process_request_v0_uniswap_swap_sell_exactly_post**](docs/UniswapV3Api.md#process_request_v0_uniswap_swap_sell_exactly_post) | **POST** /v0/uniswap/swap/sell_exactly | Trade a specific amount of a token into another.


## Documentation For Models

 - [AaveAssetPriceInfo](docs/AaveAssetPriceInfo.md)
 - [AaveBorrowCallData](docs/AaveBorrowCallData.md)
 - [AaveGetAssetPrice](docs/AaveGetAssetPrice.md)
 - [AaveGetLiquidityChange](docs/AaveGetLiquidityChange.md)
 - [AaveGetUserPositionPerToken](docs/AaveGetUserPositionPerToken.md)
 - [AaveGetUserPositionSummary](docs/AaveGetUserPositionSummary.md)
 - [AaveLiquidityChange](docs/AaveLiquidityChange.md)
 - [AaveRepayCallData](docs/AaveRepayCallData.md)
 - [AaveSupplyCallData](docs/AaveSupplyCallData.md)
 - [AaveUserPositionPerTokenInfo](docs/AaveUserPositionPerTokenInfo.md)
 - [AaveUserPositionSummaryInfo](docs/AaveUserPositionSummaryInfo.md)
 - [AaveWithdrawCallData](docs/AaveWithdrawCallData.md)
 - [AerodromeLPPositionsInfo](docs/AerodromeLPPositionsInfo.md)
 - [AerodromeLiquidityProvisionCallData](docs/AerodromeLiquidityProvisionCallData.md)
 - [AerodromeLiquidityProvisionEthCallData](docs/AerodromeLiquidityProvisionEthCallData.md)
 - [AerodromePosition](docs/AerodromePosition.md)
 - [AerodromeRemoveLiquidityCallData](docs/AerodromeRemoveLiquidityCallData.md)
 - [AerodromeRemoveLiquidityEthCallData](docs/AerodromeRemoveLiquidityEthCallData.md)
 - [AerodromeSlipstreamBuyExactlyCallData](docs/AerodromeSlipstreamBuyExactlyCallData.md)
 - [AerodromeSlipstreamGetLiquidityProvisionPositions](docs/AerodromeSlipstreamGetLiquidityProvisionPositions.md)
 - [AerodromeSlipstreamGetPoolPrice](docs/AerodromeSlipstreamGetPoolPrice.md)
 - [AerodromeSlipstreamIncreaseLiquidityProvisionCallData](docs/AerodromeSlipstreamIncreaseLiquidityProvisionCallData.md)
 - [AerodromeSlipstreamMintLiquidityProvisionCallData](docs/AerodromeSlipstreamMintLiquidityProvisionCallData.md)
 - [AerodromeSlipstreamPoolPrice](docs/AerodromeSlipstreamPoolPrice.md)
 - [AerodromeSlipstreamSellExactlyCallData](docs/AerodromeSlipstreamSellExactlyCallData.md)
 - [AerodromeSlipstreamWithdrawLiquidityProvisionCallData](docs/AerodromeSlipstreamWithdrawLiquidityProvisionCallData.md)
 - [AerodromeSwapEthForTokenCallData](docs/AerodromeSwapEthForTokenCallData.md)
 - [AerodromeSwapTokenForEthCallData](docs/AerodromeSwapTokenForEthCallData.md)
 - [AerodromeSwapTokensCallData](docs/AerodromeSwapTokensCallData.md)
 - [AllowanceInfo](docs/AllowanceInfo.md)
 - [Amount](docs/Amount.md)
 - [Amount0Desired](docs/Amount0Desired.md)
 - [Amount0Min](docs/Amount0Min.md)
 - [Amount1](docs/Amount1.md)
 - [Amount1Desired](docs/Amount1Desired.md)
 - [Amount1Min](docs/Amount1Min.md)
 - [Amount2](docs/Amount2.md)
 - [Amount3](docs/Amount3.md)
 - [Amount4](docs/Amount4.md)
 - [Amount5](docs/Amount5.md)
 - [AmountADesired](docs/AmountADesired.md)
 - [AmountAMin](docs/AmountAMin.md)
 - [AmountAMin1](docs/AmountAMin1.md)
 - [AmountBDesired](docs/AmountBDesired.md)
 - [AmountBMin](docs/AmountBMin.md)
 - [AmountBMin1](docs/AmountBMin1.md)
 - [AmountEthDesired](docs/AmountEthDesired.md)
 - [AmountEthMin](docs/AmountEthMin.md)
 - [AmountEthMin1](docs/AmountEthMin1.md)
 - [AmountIn](docs/AmountIn.md)
 - [AmountIn1](docs/AmountIn1.md)
 - [AmountIn2](docs/AmountIn2.md)
 - [AmountInMaximum](docs/AmountInMaximum.md)
 - [AmountOut](docs/AmountOut.md)
 - [AmountOutMin](docs/AmountOutMin.md)
 - [AmountOutMin1](docs/AmountOutMin1.md)
 - [AmountOutMinimum](docs/AmountOutMinimum.md)
 - [AmountTokenDesired](docs/AmountTokenDesired.md)
 - [AmountTokenMin](docs/AmountTokenMin.md)
 - [AmountTokenMin1](docs/AmountTokenMin1.md)
 - [BalanceInfo](docs/BalanceInfo.md)
 - [BaseTransactionRequestAaveBorrowCallData](docs/BaseTransactionRequestAaveBorrowCallData.md)
 - [BaseTransactionRequestAaveRepayCallData](docs/BaseTransactionRequestAaveRepayCallData.md)
 - [BaseTransactionRequestAaveSupplyCallData](docs/BaseTransactionRequestAaveSupplyCallData.md)
 - [BaseTransactionRequestAaveWithdrawCallData](docs/BaseTransactionRequestAaveWithdrawCallData.md)
 - [BaseTransactionRequestAerodromeLiquidityProvisionCallData](docs/BaseTransactionRequestAerodromeLiquidityProvisionCallData.md)
 - [BaseTransactionRequestAerodromeLiquidityProvisionEthCallData](docs/BaseTransactionRequestAerodromeLiquidityProvisionEthCallData.md)
 - [BaseTransactionRequestAerodromeRemoveLiquidityCallData](docs/BaseTransactionRequestAerodromeRemoveLiquidityCallData.md)
 - [BaseTransactionRequestAerodromeRemoveLiquidityEthCallData](docs/BaseTransactionRequestAerodromeRemoveLiquidityEthCallData.md)
 - [BaseTransactionRequestAerodromeSlipstreamBuyExactlyCallData](docs/BaseTransactionRequestAerodromeSlipstreamBuyExactlyCallData.md)
 - [BaseTransactionRequestAerodromeSlipstreamIncreaseLiquidityProvisionCallData](docs/BaseTransactionRequestAerodromeSlipstreamIncreaseLiquidityProvisionCallData.md)
 - [BaseTransactionRequestAerodromeSlipstreamMintLiquidityProvisionCallData](docs/BaseTransactionRequestAerodromeSlipstreamMintLiquidityProvisionCallData.md)
 - [BaseTransactionRequestAerodromeSlipstreamSellExactlyCallData](docs/BaseTransactionRequestAerodromeSlipstreamSellExactlyCallData.md)
 - [BaseTransactionRequestAerodromeSlipstreamWithdrawLiquidityProvisionCallData](docs/BaseTransactionRequestAerodromeSlipstreamWithdrawLiquidityProvisionCallData.md)
 - [BaseTransactionRequestAerodromeSwapEthForTokenCallData](docs/BaseTransactionRequestAerodromeSwapEthForTokenCallData.md)
 - [BaseTransactionRequestAerodromeSwapTokenForEthCallData](docs/BaseTransactionRequestAerodromeSwapTokenForEthCallData.md)
 - [BaseTransactionRequestAerodromeSwapTokensCallData](docs/BaseTransactionRequestAerodromeSwapTokensCallData.md)
 - [BaseTransactionRequestIncreaseErc20AllowanceAnyCallData](docs/BaseTransactionRequestIncreaseErc20AllowanceAnyCallData.md)
 - [BaseTransactionRequestIncreaseErc20AllowanceCallData](docs/BaseTransactionRequestIncreaseErc20AllowanceCallData.md)
 - [BaseTransactionRequestUniswapBuyExactlyCallData](docs/BaseTransactionRequestUniswapBuyExactlyCallData.md)
 - [BaseTransactionRequestUniswapIncreaseLiquidityProvisionCallData](docs/BaseTransactionRequestUniswapIncreaseLiquidityProvisionCallData.md)
 - [BaseTransactionRequestUniswapMintLiquidityProvisionCallData](docs/BaseTransactionRequestUniswapMintLiquidityProvisionCallData.md)
 - [BaseTransactionRequestUniswapSellExactlyCallData](docs/BaseTransactionRequestUniswapSellExactlyCallData.md)
 - [BaseTransactionRequestUniswapWithdrawLiquidityProvisionCallData](docs/BaseTransactionRequestUniswapWithdrawLiquidityProvisionCallData.md)
 - [BaseTransactionRequestUnwrapWethRequestCallData](docs/BaseTransactionRequestUnwrapWethRequestCallData.md)
 - [BaseTransactionRequestWrapEthRequestCallData](docs/BaseTransactionRequestWrapEthRequestCallData.md)
 - [Chain](docs/Chain.md)
 - [ContractName](docs/ContractName.md)
 - [EnsNameInfo](docs/EnsNameInfo.md)
 - [FeeEnum](docs/FeeEnum.md)
 - [GetErc20Allowance](docs/GetErc20Allowance.md)
 - [GetErc20Balance](docs/GetErc20Balance.md)
 - [GetSupportedTokens](docs/GetSupportedTokens.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [Image](docs/Image.md)
 - [IncreaseErc20AllowanceAnyCallData](docs/IncreaseErc20AllowanceAnyCallData.md)
 - [IncreaseErc20AllowanceCallData](docs/IncreaseErc20AllowanceCallData.md)
 - [InterestRateMode](docs/InterestRateMode.md)
 - [Liquidity](docs/Liquidity.md)
 - [PercentageForWithdrawal](docs/PercentageForWithdrawal.md)
 - [Portfolio](docs/Portfolio.md)
 - [RequestEnsDetails](docs/RequestEnsDetails.md)
 - [RequestUserAddress](docs/RequestUserAddress.md)
 - [Token](docs/Token.md)
 - [Token0Token1](docs/Token0Token1.md)
 - [TokenBalance](docs/TokenBalance.md)
 - [TokenInfo](docs/TokenInfo.md)
 - [UniswapBuyExactlyCallData](docs/UniswapBuyExactlyCallData.md)
 - [UniswapBuyQuoteInfo](docs/UniswapBuyQuoteInfo.md)
 - [UniswapCheckInRangeCallData](docs/UniswapCheckInRangeCallData.md)
 - [UniswapCheckInRangeResponse](docs/UniswapCheckInRangeResponse.md)
 - [UniswapGetBuyQuote](docs/UniswapGetBuyQuote.md)
 - [UniswapGetLiquidityProvisionPositions](docs/UniswapGetLiquidityProvisionPositions.md)
 - [UniswapGetPoolPrice](docs/UniswapGetPoolPrice.md)
 - [UniswapGetSellQuote](docs/UniswapGetSellQuote.md)
 - [UniswapImpermanentLossCallData](docs/UniswapImpermanentLossCallData.md)
 - [UniswapImpermanentLossResponse](docs/UniswapImpermanentLossResponse.md)
 - [UniswapIncreaseLiquidityProvisionCallData](docs/UniswapIncreaseLiquidityProvisionCallData.md)
 - [UniswapLPPositionsInfo](docs/UniswapLPPositionsInfo.md)
 - [UniswapMintLiquidityProvisionCallData](docs/UniswapMintLiquidityProvisionCallData.md)
 - [UniswapPoolPrice](docs/UniswapPoolPrice.md)
 - [UniswapPosition](docs/UniswapPosition.md)
 - [UniswapSellExactlyCallData](docs/UniswapSellExactlyCallData.md)
 - [UniswapSellQuoteInfo](docs/UniswapSellQuoteInfo.md)
 - [UniswapWithdrawLiquidityProvisionCallData](docs/UniswapWithdrawLiquidityProvisionCallData.md)
 - [UnsignedTransaction](docs/UnsignedTransaction.md)
 - [UnwrapWethRequestCallData](docs/UnwrapWethRequestCallData.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)
 - [WrapEthRequestCallData](docs/WrapEthRequestCallData.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




